pub struct JsonSyntaxError { /* private fields */ }Expand description
A JSON syntax error with byte and human-readable source coordinates.
Examples
use qubit_json::decode::{JsonSyntaxError, JsonSyntaxErrorReason};
let error = JsonSyntaxError::new(0, 1, 1,
JsonSyntaxErrorReason::UnexpectedEnd); assert_eq!(error.line(), 1);
assert_eq!(error.reason(), JsonSyntaxErrorReason::UnexpectedEnd);Implementations
Sourceimpl JsonSyntaxError
impl JsonSyntaxError
Sourcepub const fn new(
offset: usize,
line: usize,
column: usize,
reason: JsonSyntaxErrorReason,
) -> Self
pub const fn new( offset: usize, line: usize, column: usize, reason: JsonSyntaxErrorReason, ) -> Self
Creates a syntax error from a source position and stable reason.
Parameters
offset- Zero-based byte offset at which the error was observed.line- One-based source line containing the error.column- One-based UTF-8 character column containing the error.reason- Stable classification of the lexical failure.
Returns
A syntax error containing the supplied location and classification.
Sourcepub const fn offset(&self) -> usize
pub const fn offset(&self) -> usize
Returns the zero-based byte offset.
Returns
The zero-based byte offset at which the error was observed.
Sourcepub const fn column(&self) -> usize
pub const fn column(&self) -> usize
Returns the one-based UTF-8 character column.
Returns
The one-based UTF-8 character column containing the error.
Sourcepub const fn reason(&self) -> JsonSyntaxErrorReason
pub const fn reason(&self) -> JsonSyntaxErrorReason