pub enum JsonIntegerSignedness {
Signed,
Unsigned,
}Expand description
Signedness retained by an integer-range encoding failure.
Examples
use qubit_json::encode::JsonIntegerSignedness;
use qubit_json::value::JsonValueEncoder;
let error = JsonValueEncoder::new()
.encode(&u128::MAX)
.expect_err("wide integer must be rejected");
assert_eq!(error.integer_signedness(), Some(JsonIntegerSignedness::Unsigned));Variants
Signed
The source was serialized through a signed integer entry point.
Unsigned
The source was serialized through an unsigned integer entry point.