pub enum JsonSerializerStateError {
UnexpectedCompound,
MapKeyAlreadyPending,
MapValueWithoutKey,
MapEndedWithPendingKey,
InvalidRawValueProtocol,
}Expand description
Invalid state produced by a malformed hand-written Serde implementation.
Examples
use qubit_json::encode::JsonSerializationError;
use qubit_json::encode::JsonSerializationErrorKind;
use qubit_json::encode::JsonSerializerStateError;
let error = JsonSerializationError::new(JsonSerializationErrorKind::InvalidSerializerState {
reason: JsonSerializerStateError::MapValueWithoutKey,
});
assert_eq!(
error.serializer_state_error(),
Some(JsonSerializerStateError::MapValueWithoutKey),
);Variants
UnexpectedCompound
A compound callback was used with the wrong compound state.
MapKeyAlreadyPending
A split-map key was submitted before the previous key received a value.
MapValueWithoutKey
A split-map value was submitted without a preceding key.
MapEndedWithPendingKey
A split map ended while one key was still waiting for its value.
InvalidRawValueProtocol
The private serde_json RawValue protocol had an invalid shape.