#[non_exhaustive]pub enum MarkdownFenceClosing {
Optional,
Required,
}Expand description
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Optional
Accepts an opening fence even when no matching closing fence is present.
Required
Requires a matching closing fence before stripping the outer fence.