JSON decoding APIs and their diagnostics.
Structs
- Json
Decode Error - Failure produced by either strict or normalizing JSON decoding.
- Json
Decoder - Strictly decodes complete JSON documents while retaining cumulative usage.
- Json
Syntax Error - A JSON syntax error with byte and human-readable source coordinates.
- Normalized
Json Document - A normalized JSON document whose text outlives borrowed decode results.
- Normalizing
Json Decode Policy - Text-normalization and diagnostic policy for
crate::decode::NormalizingJsonDecoder. - Normalizing
Json Decode Policy Builder - Builder for
NormalizingJsonDecodePolicy. - Normalizing
Json Decoder - Normalizes non-fully-trusted text before decoding complete JSON documents.
Enums
- Diagnostic
Policy - Controls whether JSON decoding errors retain input-derived details.
- Json
Decode Error Kind - Represents the coarse category of a JSON decoding failure.
- Json
Decode Error Source - An owned semantic source extracted from a JSON decoding failure.
- Json
Decode Stage - Identifies the semantic decoding stage where a failure occurred.
- Json
Root Kind - Represents the top-level kind of a parsed JSON value.
- Json
Syntax Error Reason - The concrete reason why a JSON document was rejected lexically.
- Markdown
Fence Closing - Specifies whether an opening Markdown code fence needs a closing fence.
- Markdown
Fence Policy - Controls whether and how one outer Markdown code fence is stripped.